@@ -5,7 +5,7 @@ from typing import Literal
 from decimal import Decimal
 from decimal import ROUND_HALF_UP, ROUND_CEILING, ROUND_FLOOR
 
-from nexustrader.schema import Order, BaseMarket
+from nexustrader.schema import BaseMarket
 from nexustrader.core.entity import TaskManager
 from nexustrader.core.nautilius_core import MessageBus, LiveClock, Logger
 from nexustrader.core.cache import AsyncCache
@@ -164,13 +164,15 @@ class ExecutionManagementSystem(ABC):
         """
         Modify an order
         """
-        await self._private_connectors[account_type]._oms.modify_order(
-            oid=order_submit.oid,
-            symbol=order_submit.symbol,
-            price=order_submit.price,
-            amount=order_submit.amount,
-            side=order_submit.side,
-            **order_submit.kwargs,
+        self._task_manager.cancel_task(
+            self._private_connectors[account_type]._oms.modify_order(
+                oid=order_submit.oid,
+                symbol=order_submit.symbol,
+                price=order_submit.price,
+                amount=order_submit.amount,
+                side=order_submit.side,
+                **order_submit.kwargs,
+            )
         )
 
     async def _cancel_all_orders(
@@ -179,8 +181,10 @@ class ExecutionManagementSystem(ABC):
         """
         Cancel all orders
         """
-        await self._private_connectors[account_type]._oms.cancel_all_orders(
-            order_submit.symbol
+        symbol = order_submit.symbol
+        self._cache.mark_all_cancel_intent(symbol)
+        self._task_manager.create_task(
+            self._private_connectors[account_type]._oms.cancel_all_orders(symbol)
         )
 
     async def _cancel_order(
@@ -189,10 +193,13 @@ class ExecutionManagementSystem(ABC):
         """
         Cancel an order
         """
-        await self._private_connectors[account_type]._oms.cancel_order(
-            oid=order_submit.oid,
-            symbol=order_submit.symbol,
-            **order_submit.kwargs,
+        self._cache.mark_cancel_intent(order_submit.oid)
+        self._task_manager.create_task(
+            self._private_connectors[account_type]._oms.cancel_order(
+                oid=order_submit.oid,
+                symbol=order_submit.symbol,
+                **order_submit.kwargs,
+            )
         )
 
     async def _cancel_order_ws(
@@ -201,11 +208,13 @@ class ExecutionManagementSystem(ABC):
         """
         Cancel an order
         """
-
-        await self._private_connectors[account_type]._oms.cancel_order_ws(
-            oid=order_submit.oid,
-            symbol=order_submit.symbol,
-            **order_submit.kwargs,
+        self._cache.mark_cancel_intent(order_submit.oid)
+        self._task_manager.create_task(
+            self._private_connectors[account_type]._oms.cancel_order_ws(
+                oid=order_submit.oid,
+                symbol=order_submit.symbol,
+                **order_submit.kwargs,
+            )
         )
 
     async def _create_order(
@@ -215,16 +224,18 @@ class ExecutionManagementSystem(ABC):
         Create an order
         """
         self._registry.register_order(order_submit.oid)
-        await self._private_connectors[account_type]._oms.create_order(
-            oid=order_submit.oid,
-            symbol=order_submit.symbol,
-            side=order_submit.side,
-            type=order_submit.type,
-            amount=order_submit.amount,
-            price=order_submit.price,
-            time_in_force=order_submit.time_in_force,
-            reduce_only=order_submit.reduce_only,
-            **order_submit.kwargs,
+        self._task_manager.create_task(
+            self._private_connectors[account_type]._oms.create_order(
+                oid=order_submit.oid,
+                symbol=order_submit.symbol,
+                side=order_submit.side,
+                type=order_submit.type,
+                amount=order_submit.amount,
+                price=order_submit.price,
+                time_in_force=order_submit.time_in_force,
+                reduce_only=order_submit.reduce_only,
+                **order_submit.kwargs,
+            )
         )
 
     async def _create_order_ws(
@@ -234,16 +245,18 @@ class ExecutionManagementSystem(ABC):
         Create an order
         """
         self._registry.register_order(order_submit.oid)
-        await self._private_connectors[account_type]._oms.create_order_ws(
-            oid=order_submit.oid,
-            symbol=order_submit.symbol,
-            side=order_submit.side,
-            type=order_submit.type,
-            amount=order_submit.amount,
-            price=order_submit.price,
-            time_in_force=order_submit.time_in_force,
-            reduce_only=order_submit.reduce_only,
-            **order_submit.kwargs,
+        self._task_manager.create_task(
+            self._private_connectors[account_type]._oms.create_order_ws(
+                oid=order_submit.oid,
+                symbol=order_submit.symbol,
+                side=order_submit.side,
+                type=order_submit.type,
+                amount=order_submit.amount,
+                price=order_submit.price,
+                time_in_force=order_submit.time_in_force,
+                reduce_only=order_submit.reduce_only,
+                **order_submit.kwargs,
+            )
         )
 
     @abstractmethod
@@ -594,8 +607,10 @@ class ExecutionManagementSystem(ABC):
     ):
         for order in batch_orders:
             self._registry.register_order(order.oid)
-        await self._private_connectors[account_type]._oms.create_batch_orders(
-            orders=batch_orders,
+        self._task_manager.create_task(
+            self._private_connectors[account_type]._oms.create_batch_orders(
+                orders=batch_orders,
+            )
         )
 
     async def start(self):
